server/sources/datafeed.py
changeset 7398 26695dd703d8
parent 7385 29f050e39b09
child 7399 972ed1843bd8
--- a/server/sources/datafeed.py	Thu May 19 10:36:26 2011 +0200
+++ b/server/sources/datafeed.py	Thu May 19 10:53:11 2011 +0200
@@ -254,17 +254,17 @@
             try:
                 self.process_item(*args)
                 if partialcommit:
                     # commit+set_pool instead of commit(reset_pool=False) to let
                     # other a chance to get our pool
                     self._cw.commit()
-                    self._cw.set_pool()
+                    self._cw.set_cnxset()
             except ValidationError, exc:
                 if raise_on_error:
                     raise
                 if partialcommit:
                     self.source.error('Skipping %s because of validation error %s' % (args, exc))
                     self._cw.rollback()
-                    self._cw.set_pool()
+                    self._cw.set_cnxset()
                     error = True
                 else:
                     raise
@@ -254,17 +254,17 @@
                 self.process_item(*args)
                 if partialcommit:
-                    # commit+set_pool instead of commit(reset_pool=False) to let
-                    # other a chance to get our pool
+                    # commit+set_cnxset instead of commit(free_cnxset=False) to let
+                    # other a chance to get our connections set
                     self._cw.commit()